#<profile4xi profile = "12" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "constant_forking4xi.py">
#<abstract4xi abstract = "Provides the class ConstantForking4Xi."/>
#<refer4xi reference = "forking.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'constant_forking4xi', 'ConstantForking4Xi',
            'init_terminate_forking4xi', 'get_terminate_forking4xi', 'set_terminate_forking4xi',
            'init_winexe_forking4xi', 'get_winexe_forking4xi', 'set_winexe_forking4xi',
            'init_all_forking4xi', 'get_all_forking4xi', 'set_all_forking4xi']
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
try:                 # system ones
    import os
    import sys
    import signal
except:
    pass
try:                 # threading ones       
    import threading                
    import _thread   
except:
    pass
try:                 # winapi
    import _winapi
    from _winapi import WAIT_OBJECT_0, WAIT_TIMEOUT, INFINITE
except ImportError:
    if sys.platform == 'win32':
        raise
    _winapi = None
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
import _multiprocessing
from multiprocessing import forking
#"
#/>
     
# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from constant_system4xi import get_windows_system4xi
from print4xi import print4xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
from time4xi import time4xi
#"
#/>


# -------------------------------------------------------------------------------------------------
# Global constants                            
# ------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global TERMINATE4XI
global WINEXE4XI
#"
#/>
# -------------------------------------------------------------------------------------------------
# Settings
# -------------------------------------------------------------------------------------------------
#<set4xi setting = "
TERMINATE4XI = 0x10000
WINEXE4XI = (sys.platform == get_windows_system4xi() and getattr(sys, 'frozen', False))
#"
#"/>
                 

# -------------------------------------------------------------------------------------------------
#<function4xi function = "constant-forking4xi" usage = "
# defines constants for forking
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------
def constant_forking4xi(param_constant_forking4xi):
    ''' 
    constant_forking4xi defines constants for forking

    '''
    global TERMINATE4XI
    global WINEXE4XI
     
    class2print = 'constant_forking4xi'
    method2print = 'constant_forking4xi'
    
    message2print = "{started" + "; constant-forking4xi-started: " + str(constant_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)        
    
    message2print = "{passed" + "; param-constant-forking4xi-passed-to-constant-forking4xi: " + str(param_constant_forking4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
          
    if param_constant_forking4xi == 1:
    
        message2print = "{returning" + "; terminate4xi-returning-by-constant-forking4xi: " + str(TERMINATE4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
           
        return TERMINATE4XI
        
    if param_constant_forking4xi == 2:
    
        message2print = "{returning" + "; winexe4xi-returning-by-constant-forking4xi: " + str(WINEXE4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   

   
        return WINEXE4XI


    message2print = "{returning" + "; false-returning-by-constant-forking4xi: " + str(False) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
               
    return False

  
#</function4xi> 

     
    
#1#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-terminate-forking4xi" usage = "
# initializes TERMINATE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_terminate_forking4xi(param_init_terminate_forking4xi=0x10000):          
    '''
    init_terminate_forking4xi initializes TERMINATE4XI
    '''
    global TERMINATE4XI
  
    class2print = 'init_terminate_forking4xi'
    method2print = 'init_terminate_forking4xi'
    
    message2print = "{started" + "; init-terminate-forking4xi-started: " + str(init_terminate_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)        
    
    
    message2print = "{passed" + "; param-init-terminate-forking4xi-passed-to-init-terminate-forking4xi: " + str(param_init_terminate_forking4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
   

    TERMINATE4XI = param_init_terminate_forking4xi
    
    message2print = "{initialized" + "; terminate4xi-initialized-by-init-terminate-forking4xi to: " + str(TERMINATE4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)               
    
    message2print = "{returning" + "; init-terminate-forking4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
          
#</function4xi> 

       
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-terminate-forking4xi" usage = "
# sets TERMINATE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_terminate_forking4xi(param_set_terminate_forking4xi=0x10000):          
    '''
    set_terminate_forking4xi sets TERMINATE4XI
    '''
    global TERMINATE4XI
  
    class2print = 'set_terminate_forking4xi'
    method2print = 'set_terminate_forking4xi'

    
    message2print = "{started" + "; set-terminate-forking4xi-started: " + str(set_terminate_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)        
       
    message2print = "{passed" + "; param-set-terminate-forking4xi-passed-to-set-terminate-forking4xi: " + str(param_set_terminate_forking4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
  
 
    TERMINATE4XI = param_set_terminate_forking4xi
              
    message2print = "{set" + "; terminate4xi-set-by-set-terminate-forking4xi to: " + str(TERMINATE4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    
    message2print = "{returning" + "; set-terminate-forking4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                            
#</function4xi> 

          
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-terminate-forking4xi" usage = "
# gets TERMINATE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_terminate_forking4xi():          
    '''
    get_terminate_forking4xi gets TERMINATE4XI
    '''
    global TERMINATE4XI
    
    class2print = 'get_terminate_forking4xi'
    method2print = 'get_terminate_forking4xi'
    
    
    message2print = "{started" + "; get-terminate-forking4xi-started: " + str(get_terminate_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)        

    message2print = "{returning" + "; terminate4xi-returning-by-get-terminate-forking4xi: " + str(TERMINATE4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
               
    
    return TERMINATE4XI 


#</function4xi> 

     
#2#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-winexe-forking4xi" usage = "
# initializes WINEXE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_winexe_forking4xi(param_init_winexe_forking4xi=(sys.platform == get_windows_system4xi() and getattr(sys, 'frozen', False))):          
    '''
    init_winexe_forking4xi initializes WINEXE4XI
    '''
    global WINEXE4XI


    class2print = 'init_winexe_forking4xi'
    method2print = 'init_winexe_forking4xi'
    
    message2print = "{started" + "; init-winexe-forking4xi-started: " + str(init_winexe_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)        
    
    
    message2print = "{passed" + "; param-init-winexe-forking4xi-passed-to-init-winexe-forking4xi: " + str(param_init_winexe_forking4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
    WINEXE4XI = param_init_winexe_forking4xi
        
    
    message2print = "{initialized" + "; winexe4xi-initialized-by-init-winexe-forking4xi to: " + str(WINEXE4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)               
    
    message2print = "{returning" + "; init-winexe-forking4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                      
#</function4xi> 

   
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-winexe-forking4xi" usage = "
# sets WINEXE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_winexe_forking4xi(param_set_winexe_forking4xi=(sys.platform == get_windows_system4xi() and getattr(sys, 'frozen', False))):          
    '''
    set_winexe_forking4xi sets WINEXE4XI
    '''
    global WINEXE4XI
 

    class2print = 'set_winexe_forking4xi'
    method2print = 'set_winexe_forking4xi'
    
    message2print = "{started" + "; set-winexe-forking4xi-started: " + str(set_winexe_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
    
    message2print = "{passed" + "; param-set-winexe-forking4xi-passed-to-set-winexe-forking4xi: " + str(param_set_winexe_forking4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
      
       
    WINEXE4XI = param_set_winexe_forking4xi
        
    message2print = "{set" + "; winexe4xi-set-by-set-winexe-forking4xi to: " + str(WINEXE4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    
    message2print = "{returning" + "; winexe-forking4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                            
#</function4xi> 

       
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-winexe-forking4xi" usage = "
# gets WINEXE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_winexe_forking4xi():          
    '''
    get_winexe_forking4xi gets WINEXE4XI
    '''
    global WINEXE4XI
    
    class2print = 'get_winexe_forking4xi'
    method2print = 'get_winexe_forking4xi'
    
    message2print = "{started" + "; get-winexe-forking4xi-started: " + str(get_winexe_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)         
    

    message2print = "{returning" + "; winexe4xi-returning-by-get-winexe-forking4xi: " + str(WINEXE4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
   
    return WINEXE4XI 
#</function4xi> 

     
#All#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-all-forking4xi" usage = "
# initializes all constants for forking
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_all_forking4xi():          
    '''
    init_all_forking4xi initializes all constants for forking
    '''
    class2print = 'init_all_forking4xi'
    method2print = 'init_all_forking4xi'
    
    message2print = "{started" + "; init-all-forking4xi-started: " + str(init_all_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    
    
    init_terminate_forking4xi()
    init_winexe_forking4xi()
    
    message2print = "{returning" + "; init-all-forking4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
              
#</function4xi> 

       
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-all-forking4xi" usage = "
# sets all constants for forking
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_all_forking4xi():          
    '''
    set_all_forking4xi sets all constants for forking
    '''
    class2print = 'set_all_forking4xi'
    method2print = 'set_all_forking4xi'
    
    message2print = "{started" + "; set-all-forking4xi-started: " + str(set_all_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    
    
    set_terminate_forking4xi()
    set_winexe_forking4xi()      
    
    message2print = "{returning" + "; set-all-forking4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
             
#</function4xi> 

   
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-all-forking4xi" usage = "
# gets all process constants
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_all_forking4xi():          
    '''
    get_all_constant_forking4xi gets all process constants
    '''
    # ---------------------------------------------------------------------------------------------
    # could return True after loading an OWL/XML file into memory 
    # ---------------------------------------------------------------------------------------------    
    class2print = 'get_all_forking4xi'
    method2print = 'get_all_forking4xi'
    
    message2print = "{started" + "; get-all-forking4xi-started: " + str(get_all_forking4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)         
    
    for i in range(0,3):
        print("constant_forking4xi(", i, ") = ", constant_forking4xi(i))

    message2print = "{returning" + "; true-returning-by-get-all-forking4xi: " + str(True) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
                   
      
    return True    
#</function4xi> 

     
# =================================================================================================
# ConstantForking4Xi class
#<class4xi class = "ConstantForking4Xi" base = "object" child = "None" synopsis = "offers services for forking constants" usage = "forking"
#>
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# =================================================================================================
class ConstantForking4Xi(object): #<-- inherits from object class
    ''' 
    ConstantForking4Xi offers services for forking constants
    '''
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi expose = "
    _exposed_ = ( 'init_terminate', 'get_terminate', 'set_terminate',
                  'init_winexe', 'get_winexe', 'set_winexe',
                  'init_all', 'get_all', 'set_all',
                  'sense', 'reason', 'ace')          
    #"
    #/>
                                                 
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-of-ConstantForking4Xi" usage = "initializes forking constants">_
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def __init__(self):
        '''
        _init__ method initializes forking constants
        '''
        class2print = 'ConstantForking4Xi'
        method2print = '__init__'
        
        message2print = "{started" + "; init-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
                              
        
        message2print = "{borning" + "; constantforking2xi-of-ConstantForking4Xi-borning: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       

        message2print = "{inheriting" + "; object-inheriting-by-constantforking2xi-of-ConstantForking4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
               
        init_all_forking4xi()        
    

        message2print = "{activated" + "; constantforking2xi-of-ConstantForking4Xi-activated: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        message2print = "{inherited" + "; object-inherited-by-constantforking2xi-of-ConstantForking4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
         
        message2print = "{returning" + "; init-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                               

    #</methodize4xi>
          
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-all-of-ConstantForking4Xi" usage = "initializes forking constants">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def init_all(self):
        '''
        init_all method initializes forking constants
        '''       
        class2print = 'ConstantForking4Xi'
        method2print = 'init_all'
        
        message2print = "{started" + "; init-all-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        init_all_forking4xi()   
    
       
        message2print = "{returning" + "; init-all-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
               
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-all-of-ConstantForking4Xi" usage = "sets all forking constants">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def set_all(self):
        '''
        set_all method sets all forking constants
        '''       
        class2print = 'ConstantForking4Xi'
        method2print = 'set_all'
        
        message2print = "{started" + "; set-all-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        set_all_forking4xi() 
    
       
        message2print = "{returning" + "; set-all-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
               
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-all-of-ConstantForking4Xi" usage = "gets all forking constants">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def get_all(self):
        '''
        get_all method gets all forking constants
        '''       
        class2print = 'ConstantForking4Xi'
        method2print = 'get_all'
        
        message2print = "{started" + "; get-all-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        
        message2print = "{returning" + "; get-all-forking4xi-function-returning-by-get-all-of-ConstantForking4Xi: " + str(get_all_forking4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                        
                
        return get_all_forking4xi()     
    #</methodize4xi>
        
    #1#
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-terminate-of-ConstantForking4Xi" usage = "initializes TERMINATE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_terminate(self, param_init_terminate=0x10000):          
        '''
        init_terminate initializes TERMINATE4XI
        '''
        class2print = 'ConstantForking4Xi'
        method2print = 'init_terminate'
        
        message2print = "{started" + "; init-terminate-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
    
        message2print = "{passing" + "; param-init-terminate-passing-to-init-terminate-forking4xi-by-init-terminate-of-ConstantForking4Xi: " + str(param_init_terminate) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
                
                    
        init_terminate_forking4xi(param_init_terminate)
    
        message2print = "{returning" + "; init-terminate-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
           
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-terminate-of-ConstantForking4Xi" usage = "sets TERMINATE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_terminate(self, param_set_terminate=0x10000):          
        '''
        set_terminate sets TERMINATE4XI
        '''
        class2print = 'ConstantForking4Xi'
        method2print = 'set_terminate'
        
        message2print = "{started" + "; set-terminate-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
    
        message2print = "{passing" + "; param-set-terminate-passing-to-set-terminate-forking4xi-by-set-terminate-of-ConstantForking4Xi: " + str(param_set_terminate) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
                
                   
        set_terminate_forking4xi(param_set_terminate)
    
        message2print = "{returning" + "; set-terminate-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
           
        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-terminate-of-ConstantForking4Xi" usage = "gets TERMINATE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_terminate(self):          
        '''
        get_terminate gets TERMINATE4XI
        '''
        class2print = 'ConstantForking4Xi'
        method2print = 'get_terminate'
        
        message2print = "{started" + "; get-terminate-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        message2print = "{returning" + "; get-terminate-forking4xi-function-returning-by-get-terminate-of-ConstantForking4Xi: " + str(get_terminate_forking4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                        
        
        return get_terminate_forking4xi() 
    #</methodize4xi>
            
    #2#
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-winexe-of-ConstantForking4Xi" usage = "initializes WINEXE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_winexe(self, param_init_winexe=(sys.platform == get_windows_system4xi() and getattr(sys, 'frozen', False))):          
        '''
        init_winexe initializes WINEXE4XI
        '''
        class2print = 'ConstantForking4Xi'
        method2print = 'init_winexe'
        
        message2print = "{started" + "; init-winexe-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
    
        message2print = "{passing" + "; param-init-winexe-passing-to-init-winexe-forking4xi-by-init-winexe-of-ConstantForking4Xi: " + str(param_init_winexe) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
                
                   
        init_winexe_forking4xi(param_init_winexe)
    
       
        message2print = "{returning" + "; init-winexe-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
           
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-winexe-of-ConstantForking4Xi" usage = "sets WINEXE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_winexe(self, param_set_winexe=(sys.platform == get_windows_system4xi() and getattr(sys, 'frozen', False))):          
        '''
        set_winexe sets WINEXE4XI
        '''
        class2print = 'ConstantForking4Xi'
        method2print = 'set_winexe'
        
        message2print = "{started" + "; set-winexe-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
    
        message2print = "{passing" + "; param-set-winexe-passing-to-set-winexe-forking4xi-by-set-winexe-of-ConstantForking4Xi: " + str(param_set_winexe) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
                
                   
        set_winexe_forking4xi(param_set_winexe)
    
        message2print = "{returning" + "; set-winexe-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
               
        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-winexe-of-ConstantForking4Xi" usage = "gets WINEXE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_winexe(self):          
        '''
        get_winexe gets WINEXE4XI
        '''
        class2print = 'ConstantForking4Xi'
        method2print = 'get_winexe'
        
        message2print = "{started" + "; get-winexe-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        message2print = "{returning" + "; get-winexe-forking4xi-function-returning-by-get-winexe-of-ConstantForking4Xi: " + str(get_winexe_forking4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                        
        
        return get_winexe_forking4xi() 
    #</methodize4xi>
            
    #All#
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-all-of-ConstantForking4Xi" usage = "initializes all constants for forking">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_all(self):          
        '''
        init_all initializes all constants for forking
        '''
        class2print = 'ConstantForking4Xi'
        method2print = 'init_all'
        
        message2print = "{started" + "; init-all-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        init_terminate_forking4xi()
        init_winexe_forking4xi()
    
       
        message2print = "{returning" + "; init-all-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
               
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-all-of-ConstantForking4Xi" usage = "sets all constants for forking">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_all(self):          
        '''
        set_all sets all constants for forking
        '''
        class2print = 'ConstantForking4Xi'
        method2print = 'set_all'
        
        message2print = "{started" + "; set-all-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        set_terminate_forking4xi()
        set_winexe_forking4xi()                       
    
       
        message2print = "{returning" + "; set-all-of-ConstantForking4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
       
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-ConstantForking4Xi" usage = "senses class objects">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        senses ConstantForking4Xi class objects
        '''

        
        class2print = 'ConstantForking4Xi'
        method2print = 'sense'
        
        message2print = "{started" + "; sense-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; constantforking4xi-sensing-by-sense-of-ConstantForking4Xi: " + str(ConstantForking4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                       
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-ConstantForking4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['inheritance-of-constantforking2xi'] = object
        except:
            message2print = "{yielded" + "; kb2xi-yielded-by-sense-of-ConstantForking4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
      
        
      
        message2print = "{sensed" + "; constantforking4xi-sensed-by-sense-of-ConstantForking4Xi: " + str(ConstantForking4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)      
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-ConstantForking4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-ConstantForking4Xi" usage = "reasons class objects">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        reasons ConstantForking4Xi class objects
        '''
      
        
        class2print = 'ConstantForking4Xi'
        method2print = 'reason'

        message2print = "{started" + "; reason-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)      
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; constantforking4xi-reasoning-by-reason-of-ConstantForking4Xi: " + str(ConstantForking4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-ConstantForking4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        message2print = "{reasoned" + "; constantforking4xi-reasoned-by-reason-of-ConstantForking4Xi: " + str(ConstantForking4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-ConstantForking4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                               
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-ConstantForking4Xi" usage = "aces class objects">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        aces ConstantForking4Xi class objects 
        '''
       
        
        
        class2print = 'ConstantForking4Xi'
        method2print = 'ace'
        
        message2print = "{started" + "; ace-of-ConstantForking4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; constantforking4xi-acing-by-ace-of-ConstantForking4Xi: " + str(ConstantForking4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                     
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-ConstantForking4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; constantforking4xi-aced-by-ace-of-ConstantForking4Xi: " + str(ConstantForking4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-ConstantForking4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                  
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # ----------------------------------------------------------------------------------------- 
    #</methodize4xi>
    
#</class4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_constant_forking4xi.txt
#   sense-test-constant-forking4xi.xml
#   reason-test-constant-forking4xi.xml
#   ace-test-constant-forking4xi.xml
#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>

    
    

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of constant_forking4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>
